

class visdom_torch:
    def __init__(self, plot, update = 'reduce'):
#        assert isinstance(plot,type(Visdom().line)), "visdom.Visdom must be instantiated"
        self.plot = plot
        self.update = update
        self.win = None
    def __call__(self,**args):
        if not self.win:
            self.win = self.plot(**args)
        else:
            self.plot(**args,win = self.win, update = self.update,)
            




# setup.py
from setuptools import setup,find_packages
setup(name = 'vistorch',
      version = '0.0.1.dev1',
      description = 'use visdom on pytorch',
      author = 'xi wei',
      author_email = 'xiwei.cv@gmail.com',
      license = 'BSD',
      keywords = 'visdom torch',
      packages = ['vistorch']
      )
